/*****************************************************************************
** FILE IDENTIFICATION
**
**   Name:          ctsim.cpp
**   Purpose:       Top-level routines for CTSim program
**   Programmer:    Kevin Rosenberg
**   Date Started:  July 2000
**
**  This is part of the CTSim program
**  Copyright (C) 1983-2000 Kevin Rosenberg
**
**  $Id: ctsim.h,v 1.13 2000/12/25 21:54:26 kevin Exp $
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License (version 2) as
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/

#ifndef __CTSIMH__
#define __CTSIMH__

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
#ifdef HAVE_DMALLOC
#include <dmalloc.h>
#endif

class wxMenu;
class wxDocument;
class ImageFileDocument;
#include <vector>

#include "wx/docview.h"

// Define a new frame for main window
class MainFrame: public wxDocParentFrame
{
    DECLARE_CLASS(MainFrame)
private:
    wxTextCtrl* m_pLog;
    wxMenu* m_pWindowMenu;

    enum { MAX_WINDOW_MENUITEMS = 20 };
    wxMenuItem* m_apWindowMenuItems[MAX_WINDOW_MENUITEMS];
    wxDocument* m_apWindowMenuData[MAX_WINDOW_MENUITEMS];

public:
    MainFrame(wxDocManager *manager, wxFrame *frame, wxWindowID id, const wxString& title, const wxPoint& pos, const wxSize& size, const long type);
    
    void OnAbout (wxCommandEvent& event);
    void OnHelpContents (wxCommandEvent& event);
    void OnCreatePhantom (wxCommandEvent& event);
    void OnExit (wxCommandEvent& event);

    void OnUpdateUI (wxUpdateUIEvent& event);

    wxTextCtrl* getLog() 
	{ return m_pLog; }

    void OnWindowMenu0 (wxCommandEvent& event);
    void OnWindowMenu1 (wxCommandEvent& event);
    void OnWindowMenu2 (wxCommandEvent& event);
    void OnWindowMenu3 (wxCommandEvent& event);
    void OnWindowMenu4 (wxCommandEvent& event);
    void OnWindowMenu5 (wxCommandEvent& event);
    void OnWindowMenu6 (wxCommandEvent& event);
    void OnWindowMenu7 (wxCommandEvent& event);
    void OnWindowMenu8 (wxCommandEvent& event);
    void OnWindowMenu9 (wxCommandEvent& event);
    void OnWindowMenu10 (wxCommandEvent& event);
    void OnWindowMenu11 (wxCommandEvent& event);
    void OnWindowMenu12 (wxCommandEvent& event);
    void OnWindowMenu13 (wxCommandEvent& event);
    void OnWindowMenu14 (wxCommandEvent& event);
    void OnWindowMenu15 (wxCommandEvent& event);
    void OnWindowMenu16 (wxCommandEvent& event);
    void OnWindowMenu17 (wxCommandEvent& event);
    void OnWindowMenu18 (wxCommandEvent& event);
    void OnWindowMenu19 (wxCommandEvent& event);

    void DoWindowMenu (int iMenuPosition, wxCommandEvent& event);

    DECLARE_EVENT_TABLE()
};


class wxDocManager;
class CTSimApp: public wxApp
{
public:
    CTSimApp();
    bool OnInit();
    int OnExit();
    MainFrame* getMainFrame() const
      { return m_pFrame; }
    wxTextCtrl* getLog()
      { return m_pFrame->getLog(); }
    wxDocManager* getDocManager() 
	{ return m_docManager; }

    wxString getUntitledFilename();

    void getCompatibleImages (const ImageFileDocument* pIFDoc, std::vector<ImageFileDocument*>& vecIF);

    bool getSetModifyNewDocs() const
    { return false; }

private:
    wxDocManager* m_docManager;
    MainFrame* m_pFrame;

    void usage (const char* program);

    static struct option ctsimOptions[];

    enum { O_HELP, O_VERSION };
};

DECLARE_APP(CTSimApp)

extern class CTSimApp* theApp;


enum {
    MAINMENU_HELP_ABOUT = 500,
    MAINMENU_HELP_CONTENTS,
    MAINMENU_FILE_CREATE_PHANTOM,
    MAINMENU_FILE_EXIT,
    IFMENU_FILE_PROPERTIES,
    PJMENU_FILE_PROPERTIES,
    PHMMENU_FILE_PROPERTIES,
    PJMENU_PROCESS_RECONSTRUCT,
	IFMENU_PLOT_ROW,
	IFMENU_PLOT_COL,
    IFMENU_VIEW_SCALE_AUTO,
    IFMENU_VIEW_SCALE_MINMAX,
	IFMENU_COMPARE_IMAGES,
	IFMENU_COMPARE_ROW,
	IFMENU_COMPARE_COL,
    PHMMENU_PROCESS_RASTERIZE,
    PHMMENU_PROCESS_PROJECTIONS,
	PLOTMENU_VIEW_SCALE_MINMAX,
	PLOTMENU_VIEW_SCALE_AUTO,
    MAINMENU_WINDOW_BASE,
};

#endif
