/*****************************************************************************
** FILE IDENTIFICATION
**
**   Name:          docs.h
**   Purpose:       Header file for Document routines of CTSim program
**   Programmer:    Kevin Rosenberg
**   Date Started:  July 2000
**
**  This is part of the CTSim program
**  Copyright (C) 1983-2000 Kevin Rosenberg
**
**  $Id: docs.h,v 1.9 2000/12/27 03:16:02 kevin Exp $
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License (version 2) as
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/

#ifdef __GNUG__
// #pragma interface
#endif

#ifndef __DOCSH__
#define __DOCSH__

#include "wx/docview.h"

#include "imagefile.h"
#include "phantom.h"
#include "projections.h"
#include "plotfile.h"

class ImageFileDocument: public wxDocument
{
    DECLARE_DYNAMIC_CLASS(ImageFileDocument)
private:
    ImageFile m_imageFile;

public:
    virtual bool OnSaveDocument (const wxString& filename);
    virtual bool OnOpenDocument (const wxString& filename);
    virtual bool IsModified () const;
    virtual bool OnCloseDocument ();
    virtual void Modify (bool mod);
    
    ImageFileDocument () {}
    ~ImageFileDocument () {}

    const ImageFile& getImageFile() const
	{ return m_imageFile; }

    ImageFile& getImageFile()
	{ return m_imageFile; }
};


class ProjectionFileDocument: public wxDocument
{
    DECLARE_DYNAMIC_CLASS(ProjectionFileDocument)
private:
    Projections m_projectionFile;

public:
    virtual bool OnSaveDocument (const wxString& filename);
    virtual bool OnOpenDocument (const wxString& filename);
    virtual bool IsModified () const;
    virtual bool OnCloseDocument ();
    virtual void Modify (bool mod);
    
    ProjectionFileDocument () {}
    ~ProjectionFileDocument () {}

    const Projections& getProjections () const
	{ return m_projectionFile; }

    Projections& getProjections ()
	{ return m_projectionFile; }
};


class PhantomDocument: public wxDocument
{
    DECLARE_DYNAMIC_CLASS(PhantomDocument)

private:
    Phantom m_phantom;
    int m_idPhantom;
    wxString m_namePhantom;

public:
    PhantomDocument () 
	: m_idPhantom(Phantom::PHM_INVALID)
	{}

    ~PhantomDocument () 
	{}

    const int getPhantomID () const
	{ return m_idPhantom; }

    const wxString& getPhantomName () const
	{ return m_namePhantom; }

    const Phantom& getPhantom () const
	{ return m_phantom; }

    Phantom& getPhantom ()
	{ return m_phantom; }

    virtual bool OnOpenDocument (const wxString& filename);
    virtual bool OnCloseDocument ();
    virtual bool IsModified () const;
    virtual void Modify (bool mod);
};


class PlotFileDocument: public wxDocument
{
    DECLARE_DYNAMIC_CLASS(PlotFileDocument)

private:
    PlotFile m_plot;
    wxString m_namePlot;

public:
    PlotFileDocument () 
	{}

    ~PlotFileDocument () 
	{}

    const wxString& getPlotName () const
	{ return m_namePlot; }

    const PlotFile& getPlotFile () const
	{ return m_plot; }

    PlotFile& getPlotFile ()
	{ return m_plot; }

    virtual bool OnOpenDocument (const wxString& filename);
    virtual bool OnSaveDocument (const wxString& filename);
    virtual bool OnCloseDocument ();
    virtual bool IsModified () const;
    virtual void Modify (bool mod);
};


#endif
