/*****************************************************************************
** FILE IDENTIFICATION
**
**   Name:          view.h
**   Purpose:       Header file for View & Canvas routines of CTSim program
**   Programmer:    Kevin Rosenberg
**   Date Started:  July 2000
**
**  This is part of the CTSim program
**  Copyright (C) 1983-2000 Kevin Rosenberg
**
**  $Id: views.h,v 1.16 2000/12/22 04:18:00 kevin Exp $
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License (version 2) as
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/

#ifdef __GNUG__
// #pragma interface
#endif

#ifndef __VIEWSH__
#define __VIEWSH__

#include "wx/wx.h"
#include "docs.h"
#include "imagefile.h"

class ImageFileCanvas;
class ImageFileView : public wxView
{
    DECLARE_DYNAMIC_CLASS(ImageFileView)

    wxMemoryDC m_memoryDC;
    wxBitmap m_bitmap;

private:
    ImageFileCanvas *CreateCanvas(wxView *view, wxFrame *parent);
    wxFrame *CreateChildFrame(wxDocument *doc, wxView *view);

    ImageFileCanvas *m_canvas;
    wxFrame *m_frame;
    bool m_bMinSpecified;
    bool m_bMaxSpecified;
    double m_dMinPixel;
    double m_dMaxPixel;
    double m_dAutoScaleFactor;

public:
    ImageFileView(void);
    virtual ~ImageFileView(void);

    bool OnCreate(wxDocument *doc, long flags);
    void OnDraw(wxDC* dc);
    void OnUpdate(wxView *sender, wxObject *hint = NULL);
    bool OnClose (bool deleteWindow = true);
    void OnProperties (wxCommandEvent& event);
    void OnCompare (wxCommandEvent& event);
    void OnScaleAuto (wxCommandEvent& event);
    void OnScaleMinMax (wxCommandEvent& event);
	  void OnPlotRow (wxCommandEvent& event);
	  void OnPlotCol (wxCommandEvent& event);
    void OnCompareRow (wxCommandEvent& event);
    void OnCompareCol (wxCommandEvent& event);

	wxFrame* getFrame()
	{ return m_frame; }

    ImageFileDocument* GetDocument(void) 
	{ return dynamic_cast<ImageFileDocument*>(wxView::GetDocument()); }

    DECLARE_EVENT_TABLE()
};

class ImageFileCanvas: public wxScrolledWindow
{
private:
	int m_xCursor;
	int m_yCursor;

public:
    ImageFileView* m_pView;
    
    ImageFileCanvas (ImageFileView* v, wxFrame *frame, const wxPoint& pos, const wxSize& size, const long style);
    virtual void OnDraw(wxDC& dc);
    void OnMouseEvent(wxMouseEvent& event);

	void DrawRubberBandCursor (wxDC& dc, int x, int y);
	bool GetCurrentCursor (int& x, int& y);

    DECLARE_EVENT_TABLE()
};


class ProjectionFileCanvas;
class ProjectionFileView : public wxView
{
    DECLARE_DYNAMIC_CLASS(ProjectionFileView)

    wxMemoryDC m_memoryDC;
    wxBitmap m_bitmap;

private:
    ProjectionFileCanvas *CreateCanvas(wxView *view, wxFrame *parent);
    wxFrame *CreateChildFrame(wxDocument *doc, wxView *view);

    ProjectionFileCanvas *m_canvas;
    wxFrame *m_frame;

    int m_iDefaultNX;
    int m_iDefaultNY;
    int m_iDefaultFilter;
    int m_iDefaultFilterMethod;
    double m_dDefaultFilterParam;
    int m_iDefaultFilterGeneration;
    int m_iDefaultZeropad;
    int m_iDefaultInterpolation;
    int m_iDefaultInterpParam;
    int m_iDefaultBackprojector;
    int m_iDefaultTrace;

public:
    ProjectionFileView(void);
    virtual ~ProjectionFileView(void);

    bool OnCreate(wxDocument *doc, long flags);
    void OnDraw(wxDC* dc);
    void OnUpdate(wxView *sender, wxObject *hint = NULL);
    bool OnClose (bool deleteWindow = true);
    void OnProperties (wxCommandEvent& event);
    void OnReconstruct (wxCommandEvent& event);

	wxFrame* getFrame ()
	{ return m_frame; }

    ProjectionFileDocument* GetDocument(void) 
	{ return dynamic_cast<ProjectionFileDocument*>(wxView::GetDocument()); }
    DECLARE_EVENT_TABLE()
};

class ProjectionFileCanvas: public wxScrolledWindow
{
public:
    ProjectionFileView* m_pView;
    
    ProjectionFileCanvas (ProjectionFileView* v, wxFrame *frame, const wxPoint& pos, const wxSize& size, const long style);
    virtual void OnDraw(wxDC& dc);
};


class PhantomCanvas;
class PhantomView : public wxView
{
    DECLARE_DYNAMIC_CLASS(PhantomView)

private:
    PhantomCanvas *CreateCanvas(wxView *view, wxFrame *parent);
    wxFrame *CreateChildFrame(wxDocument *doc, wxView *view);

    PhantomCanvas *m_canvas;
    wxFrame *m_frame;

    int m_iDefaultNDet;
    int m_iDefaultNView;
    int m_iDefaultNSample;
    int m_iDefaultGeometry;
    int m_iDefaultTrace;
    double m_dDefaultRotation;
    double m_dDefaultFocalLength;
    double m_dDefaultFieldOfView;

public:
    PhantomView(void);
    virtual ~PhantomView(void);

    bool OnCreate(wxDocument *doc, long flags);
    void OnUpdate(wxView *sender, wxObject *hint = NULL);
    bool OnClose (bool deleteWindow = true);
    void OnDraw(wxDC* dc);
    void OnProperties (wxCommandEvent& event);
    void OnRasterize (wxCommandEvent& event);
    void OnProjections (wxCommandEvent& event);

    PhantomDocument* GetDocument(void) 
	{ return dynamic_cast<PhantomDocument*>(wxView::GetDocument()); }

    DECLARE_EVENT_TABLE()
};

class PhantomCanvas: public wxScrolledWindow
{
public:
    PhantomView* m_pView;
    
    PhantomCanvas (PhantomView* v, wxFrame *frame, const wxPoint& pos, const wxSize& size, const long style);

    virtual void OnDraw(wxDC& dc);

};

class PlotFileCanvas;
class PlotFileView : public wxView
{
    DECLARE_DYNAMIC_CLASS(PlotFileView)

private:
    PlotFileCanvas *CreateCanvas(wxView *view, wxFrame *parent);
    wxFrame *CreateChildFrame(wxDocument *doc, wxView *view);

    PlotFileCanvas *m_canvas;
    wxFrame *m_frame;
    bool m_bMinSpecified;
    bool m_bMaxSpecified;
    double m_dMinPixel;
    double m_dMaxPixel;
    double m_dAutoScaleFactor;

public:
    PlotFileView(void);
    virtual ~PlotFileView(void);

    bool OnCreate(wxDocument *doc, long flags);
    void OnDraw(wxDC* dc);
    void OnUpdate(wxView *sender, wxObject *hint = NULL);
    bool OnClose (bool deleteWindow = true);
    void OnProperties (wxCommandEvent& event);
    void OnScaleAuto (wxCommandEvent& event);
    void OnScaleMinMax (wxCommandEvent& event);

	wxFrame* getFrame ()
	{ return m_frame; }

    PlotFileDocument* GetDocument(void) 
	{ return dynamic_cast<PlotFileDocument*>(wxView::GetDocument()); }

    DECLARE_EVENT_TABLE()
};

class PlotFileCanvas: public wxScrolledWindow
{
public:
    PlotFileView* m_pView;
    
    PlotFileCanvas (PlotFileView* v, wxFrame *frame, const wxPoint& pos, const wxSize& size, const long style);
    virtual void OnDraw(wxDC& dc);
};



#endif

